#!/bin/sh
#
# rinologserver    Starts, Stops and Reloads Log Service for RINO Services.
#
# chkconfig: 2345 90 60
# description: RINO Log daemon.
# processname: RINOLogServer
# pidfile: /var/run/RINOLogServer.pid
#

# Installation directory
RLS_BIN=/var/rino/RINOLogServer

# Source function library.
. /etc/rc.d/init.d/functions

if ! [ -x $RLS_BIN/RINOLogServer ] ; then
	echo "ERROR: $RLS_BIN/RINOLogServer not found"
	exit 0
fi

# Full path to logserver binary
DAEMON=$RLS_BIN/RINOLogServer

RETVAL=0

start() {
	echo -n $"Starting rinologserver: "
	$DAEMON&
	RETVAL=$?
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/RINOLogServer
	echo
	return $RETVAL
}

stop() {
	echo -n $"Stopping rinologserver: "
	sleep 3s
	killproc $DAEMON
	RETVAL=$?
	[ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/RINOLogServer
	echo
	return $RETVAL
}

restart() {
	stop
	start
}

rinologserver_status() {
	if [ -f /var/lock/subsys/RINOLogServer ]; then
	    echo $"rinologserver is runnig"
	    return 0
	else
	    echo $"rinologserver is stopped"
	    return 3
	fi
}

case "$1" in
  start)
	[ -f /var/lock/subsys/RINOLogServer ] && stop || :
	start
	#status rinologserver
	rinologserver_status
	RETVAL=$?
	;;
  stop)
	stop
	#status rinologserver
	rinologserver_status
	RETVAL=$?
	;;
  restart)
	restart
	;;
  condrestart)
	[ -f /var/lock/subsys/RINOLogServer ] && restart || :
	;;
  status)
	#status rinologserver
	rinologserver_status
	RETVAL=$?
	;;
  *)
	echo "Usage: rinologserver {start|stop|restart|condrestart|status}"
	exit 1
esac

exit $?
